##
##  mosquitto-auth-ldap.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base 0.1.3
%define       V_snap 20240324

#   package information
Name:         mosquitto-auth-ldap
Summary:      LDAP Authentication for Mosquitto MQTT Broker
URL:          https://github.com/jpmens/mosquitto-auth-plug
Vendor:       Jan-Piet Mens
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MIT
Version:      %{V_base}.%{V_snap}
Release:      20240324

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/mosquitto-auth-plug/mosquitto-auth-plug-%{V_snap}.tar.xz
Source1:      mosquitto-auth-ldap.conf
Patch0:       mosquitto-auth-ldap.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  mosquitto, openldap, openssl
PreReq:       mosquitto, openldap, openssl

%description
    This is a plugin to authenticate Mosquitto MQTT broker users via
    an LDAP service. The authorization is still performed through the
    regular Mosquitto ACL file.

%track
    prog mosquitto-auth-ldap:release = {
        version   = %{V_base}
        url       = https://github.com/jpmens/mosquitto-auth-plug/releases
        regex     = tree/(__VER__)
    }
    prog mosquitto-auth-ldap:snapshot = {
        version   = %{V_snap}
        url       = http://download.openpkg.org/components/versioned/mosquitto-auth-plug/
        regex     = mosquitto-auth-plug-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n mosquitto-auth-plug
    %patch -p0

%build
    #   build plugin
    cp config.mk.in config.mk
    %{l_make} %{l_mflags} \
        CC="%{l_cc}" \
        CXX="%{l_cxx}" \
        CFG_CFLAGS="%{l_cflags -O} %{l_cppflags}" \
        CFG_LDFLAGS="%{l_ldflags}" \
        OPENSSLDIR=%{l_prefix} \
        MOSQUITTO_SRC=%{l_prefix} \
        BACKEND_LDAP=yes \
        BACKEND_CDB=no \
        BACKEND_MYSQL=no \
        BACKEND_SQLITE=no \
        BACKEND_POSTGRES=no \
        BACKEND_REDIS=no \
        BACKEND_HTTP=no \
        BACKEND_JWT=no \
        BACKEND_MONGO=no \
        BACKEND_FILES=yes \
        BACKEND_MEMCACHED=no

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/mosquitto/mosquitto.d \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/mosquitto

    #   install configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE mosquitto-auth-ldap.conf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/mosquitto/mosquitto.d/

    #   install plugin
    %{l_shtool} install -c -m 755 \
        auth-plug.so $RPM_BUILD_ROOT%{l_prefix}/libexec/mosquitto/mosquitto-auth-ldap.so

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/mosquitto/mosquitto.d/*'

%files -f files

%clean

